# Metroid Prime Randomized Layout Generator

### Difficulty:

#### Normal

This difficulty requires no special tricks or techniques and should be completable by anyone.

### Item Quantities:

#### All

All items are present in their original quantities.

#### Some

Approximately 50% of optional items are removed.

#### None

All optional items are removed. Good luck!

#### Custom

Select to reveal table.

Missile
Energy Tank
Thermal Visor
X-Ray Visor
Varia Suit
Gravity Suit
Phazon Suit
Morph Ball
Boost Ball
Spider Ball
Morph Ball Bomb
Power Bomb Expansion
Power Bomb
Charge Beam
Space Jump Boots
Grapple Beam
Super Missile
Wavebuster
Ice Spreader
Flamethrower
Ice Beam
Wave Beam
Plasma Beam
Artifact of Lifegiver
Artifact of Wild
Artifact of World
Artifact of Sun
Artifact of Elder
Artifact of Spirit
Artifact of Truth
Artifact of Chozo
Artifact of Warrior
Artifact of Newborn
Artifact of Nature
Artifact of Strength
Nothings 0